curvelets package
=================

.. automodule:: curvelets
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   curvelets.numpy
   curvelets.plot
   curvelets.reference
   curvelets.utils
